@@ -13,6 +13,19 @@ class Child(Object):
         super(Child, self).__init__(*args, **kwargs)
 
 
+class Color(Object):
+
+    """
+    :type id: int
+    """
+
+    def __init__(self, *args, **kwargs):
+        self.id = None
+        self.title = None
+
+        super(Color, self).__init__(*args, **kwargs)
+
+
 class Category(Object):
 
     """
